Function spandex::parser::utils::is_new_line [−][src]
pub fn is_new_line(content: &str, byte: usize) -> boolExpand description
Returns true if the char at specified byte is a \n.
pub fn is_new_line(content: &str, byte: usize) -> boolReturns true if the char at specified byte is a \n.